lists.openwall.net   lists  /  announce  owl-users  owl-dev  john-users  john-dev  passwdqc-users  yescrypt  popa3d-users  /  oss-security  kernel-hardening  musl  sabotage  tlsify  passwords  /  crypt-dev  xvendor  /  Bugtraq  Full-Disclosure  linux-kernel  linux-netdev  linux-ext4  linux-hardening  linux-cve-announce  PHC 
Open Source and information security mailing list archives
 
Hash Suite: Windows password security audit tool. GUI, reports in PDF.
[<prev] [next>] [<thread-prev] [thread-next>] [day] [month] [year] [list]
Date:	Fri, 08 Sep 2006 16:32:42 +0100
From:	David Howells <dhowells@...hat.com>
To:	torvalds@...l.org, akpm@...l.org, mingo@...e.hu,
	benh@...nel.crashing.org
Cc:	linux-kernel@...r.kernel.org, uclinux-dev@...inux.org,
	dhowells@...hat.com
Subject: [PATCH 3/3] FRV: Mark __do_IRQ() deprecated

From: David Howells <dhowells@...hat.com>

Mark __do_IRQ() as being deprecated (as Ben Herrenschmidt says it is).

Rename the real __do_IRQ() to __do_IRQ_deprecated() and wrap this in an inline
function called __do_IRQ() that is deprecated to prevent generic_handle_irq()
from giving deprecation warnings on every file.

Signed-Off-By: David Howells <dhowells@...hat.com>
---

 include/linux/irq.h |   11 +++++++++--
 kernel/irq/handle.c |    6 ++++--
 2 files changed, 13 insertions(+), 4 deletions(-)

diff --git a/include/linux/irq.h b/include/linux/irq.h
index 48d3cb3..83bf988 100644
--- a/include/linux/irq.h
+++ b/include/linux/irq.h
@@ -319,9 +319,16 @@ handle_irq_name(void fastcall (*handle)(
 /*
  * Monolithic do_IRQ implementation.
  * (is an explicit fastcall, because i386 4KSTACKS calls it from assembly)
+ * - This is obsolete; generic_handle_irq() should be used instead.
  */
 #ifndef CONFIG_GENERIC_HARDIRQS_NO__DO_IRQ
-extern fastcall unsigned int __do_IRQ(unsigned int irq, struct pt_regs *regs);
+extern fastcall unsigned int __do_IRQ_deprecated(unsigned int irq, struct pt_regs *regs);
+
+static inline __deprecated fastcall
+unsigned int __do_IRQ(unsigned int irq, struct pt_regs *regs)
+{
+	return __do_IRQ_deprecated(irq, regs);
+}
 #endif
 
 /*
@@ -340,7 +347,7 @@ #else
 	if (likely(desc->handle_irq))
 		desc->handle_irq(irq, desc, regs);
 	else
-		__do_IRQ(irq, regs);
+		__do_IRQ_deprecated(irq, regs);
 #endif
 }
 
diff --git a/kernel/irq/handle.c b/kernel/irq/handle.c
index 2e9e800..f3b1615 100644
--- a/kernel/irq/handle.c
+++ b/kernel/irq/handle.c
@@ -151,7 +151,7 @@ irqreturn_t handle_IRQ_event(unsigned in
 
 #ifndef CONFIG_GENERIC_HARDIRQS_NO__DO_IRQ
 /**
  * __do_IRQ - original all in one highlevel IRQ handler
  * @irq:	the interrupt number
  * @regs:	pointer to a register structure
  *
@@ -161,8 +161,10 @@ #ifndef CONFIG_GENERIC_HARDIRQS_NO__DO_I
  *
  * This is the original x86 implementation which is used for every
  * interrupt type.
+ *
+ * This is obsolete; generic_handle_irq() should be used instead.
  */
-fastcall unsigned int __do_IRQ(unsigned int irq, struct pt_regs *regs)
+fastcall unsigned int __do_IRQ_deprecated(unsigned int irq, struct pt_regs *regs)
 {
 	struct irq_desc *desc = irq_desc + irq;
 	struct irqaction *action;
-
@@ -151,7 +151,7 @@ irqreturn_t handle_IRQ_event(unsigned in
 #ifndef CONFIG_GENERIC_HARDIRQS_NO__DO_IRQ
 /**
- * __do_IRQ - original all in one highlevel IRQ handler
+ * __do_IRQ_deprecated - original all in one highlevel IRQ handler
  * @irq:	the interrupt number
  * @regs:	pointer to a register structure
To unsubscribe from this list: send the line "unsubscribe linux-kernel" in
the body of a message to majordomo@...r.kernel.org
More majordomo info at  http://vger.kernel.org/majordomo-info.html
Please read the FAQ at  http://www.tux.org/lkml/

Powered by blists - more mailing lists

Powered by Openwall GNU/*/Linux Powered by OpenVZ